/* Replication File for 
 "Foreign Aid and Government Legitimacy"
 Simone Dietrich and Matthew S. Winters
 Journal of Experimental Political Science */
 
clear
use "DietrichWinters_JEPS_2014_Replication.dta"

/*****************/
/* BALANCE CHECK */
/*****************/

mlogit treatment age male edu income news unemp student retired ftwork agwork hiv2 hiv4 hiv5 pol_index 

/***********/
/* TABLE 1 */
/***********/

* Foreign Aid Contribution to Social Services
ttest f, by(t_USOnlyvControl)
ttest f, by(t_USLocalvControl)
ttest f, by(t_USINGOvControl)
ttest f, by(t_CvControl)
ttest f, by(t_USvControl)		/* Not reported in current table */
ttest f, by(t_foreign)			/* Not reported in current table */ 

* Prime Minister Favorability Rating
ttest insts_1, by(t_USOnlyvControl)
ttest insts_1, by(t_USLocalvControl)
ttest insts_1, by(t_USINGOvControl)
ttest insts_1, by(t_CvControl)
ttest insts_1, by(t_USvControl)		/* Not reported in current table */
ttest insts_1, by(t_foreign)		/* Not reported in current table */

* Lok Sabha Favorability Rating
ttest insts_2, by(t_USOnlyvControl)
ttest insts_2, by(t_USLocalvControl)
ttest insts_2, by(t_USINGOvControl)
ttest insts_2, by(t_CvControl)
ttest insts_2, by(t_USvControl)		/* Not reported in current table */
ttest insts_2, by(t_foreign)		/* Not reported in current table */

* National Government Performance on HIV/AIDS
ttest nat, by(t_USOnlyvControl)
ttest nat, by(t_USLocalvControl)
ttest nat, by(t_USINGOvControl)
ttest nat, by(t_CvControl)
ttest nat, by(t_USvControl)		/* Not reported in current table */
ttest nat, by(t_foreign)		/* Not reported in current table */

* State Government Performance on HIV/AIDS
ttest s, by(t_USOnlyvControl)
ttest s, by(t_USLocalvControl)
ttest s, by(t_USINGOvControl)
ttest s, by(t_CvControl)
ttest s, by(t_USvControl)		/* Not reported in current table */
ttest s, by(t_foreign)			/* Not reported in current table */

/*****************************/
/* REGRESSION-BASED ANALYSIS */
/*****************************/

reg insts_1 t_foreign male age edu income news	/* p < 0.216 -- p < 0.213 in the t-test */
reg insts_2 t_foreign male age edu income news  /* p < 0.147 -- p < 0.162 in the t-test */
reg nat t_USvControl male age edu income news	/* p < 0.186 -- p < 0.175 in the t-test */
reg s t_USvControl male age edu income news		/* p < 0.668 -- p < 0.671 in the t-test */
 
/**********************/
/* SUB-GROUP ANALYSES */
/**********************/

/* Sub-Group #1: News Watchers -- Those Who Read Newspaper or Watch News Daily */
/* Hypothesis: News watchers are better informed and so will have stronger reactions to the treatments */

* Foreign Aid Contribution to Social Services
ttest f if news==1, by(t_USOnlyvControl)			
ttest f if news==1, by(t_USLocalvControl)			
ttest f if news==1, by(t_USINGOvControl)			
ttest f if news==1, by(t_CvControl)
ttest f if news==1, by(t_USvControl)
ttest f if news==1, by(t_foreign)					

* Prime Minister Favorability Rating
ttest insts_1 if news==1, by(t_USOnlyvControl)		
ttest insts_1 if news==1, by(t_USLocalvControl)		
ttest insts_1 if news==1, by(t_USINGOvControl)
ttest insts_1 if news==1, by(t_CvControl)
ttest insts_1 if news==1, by(t_USvControl)
ttest insts_1 if news==1, by(t_foreign)

* Lok Sabha Favorability Rating
ttest insts_2 if news==1, by(t_USOnlyvControl)		
ttest insts_2 if news==1, by(t_USLocalvControl)		
ttest insts_2 if news==1, by(t_USINGOvControl)		
ttest insts_2 if news==1, by(t_CvControl)			
ttest insts_2 if news==1, by(t_USvControl)
ttest insts_2 if news==1, by(t_foreign)

* National Government Performance on HIV/AIDS
ttest nat if news==1, by(t_USOnlyvControl)			
ttest nat if news==1, by(t_USLocalvControl)			
ttest nat if news==1, by(t_USINGOvControl)			
ttest nat if news==1, by(t_CvControl)				
ttest nat if news==1, by(t_USvControl)
ttest nat if news==1, by(t_foreign)

* State Government Performance on HIV/AIDS
ttest s if news==1, by(t_USOnlyvControl)			
ttest s if news==1, by(t_USLocalvControl)
ttest s if news==1, by(t_USINGOvControl)
ttest s if news==1, by(t_CvControl)					
ttest s if news==1, by(t_USvControl)
ttest s if news==1, by(t_foreign)

/* Sub-Group #2: Politically Active (Those Scoring in Top Third of Political Activity Index) */
/* Hypothesis: Politically active will have stronger reactions to the treatments */

* Foreign Aid Contribution to Social Services
ttest f if pol_topthird==1, by(t_USOnlyvControl)			
ttest f if pol_topthird==1, by(t_USLocalvControl)			
ttest f if pol_topthird==1, by(t_USINGOvControl)			
ttest f if pol_topthird==1, by(t_CvControl)
ttest f if pol_topthird==1, by(t_USvControl)
ttest f if pol_topthird==1, by(t_foreign)					

* Prime Minister Favorability Rating
ttest insts_1 if pol_topthird==1, by(t_USOnlyvControl)		
ttest insts_1 if pol_topthird==1, by(t_USLocalvControl)		
ttest insts_1 if pol_topthird==1, by(t_USINGOvControl)
ttest insts_1 if pol_topthird==1, by(t_CvControl)
ttest insts_1 if pol_topthird==1, by(t_USvControl)
ttest insts_1 if pol_topthird==1, by(t_foreign)

* Lok Sabha Favorability Rating
ttest insts_2 if pol_topthird==1, by(t_USOnlyvControl)		
ttest insts_2 if pol_topthird==1, by(t_USLocalvControl)		
ttest insts_2 if pol_topthird==1, by(t_USINGOvControl)		
ttest insts_2 if pol_topthird==1, by(t_CvControl)			
ttest insts_2 if pol_topthird==1, by(t_USvControl)
ttest insts_2 if pol_topthird==1, by(t_foreign)

* National Government Performance on HIV/AIDS
ttest nat if pol_topthird==1, by(t_USOnlyvControl)			
ttest nat if pol_topthird==1, by(t_USLocalvControl)			
ttest nat if pol_topthird==1, by(t_USINGOvControl)			
ttest nat if pol_topthird==1, by(t_CvControl)				
ttest nat if pol_topthird==1, by(t_USvControl)
ttest nat if pol_topthird==1, by(t_foreign)

* State Government Performance on HIV/AIDS
ttest s if pol_topthird==1, by(t_USOnlyvControl)			
ttest s if pol_topthird==1, by(t_USLocalvControl)
ttest s if pol_topthird==1, by(t_USINGOvControl)
ttest s if pol_topthird==1, by(t_CvControl)					
ttest s if pol_topthird==1, by(t_USvControl)
ttest s if pol_topthird==1, by(t_foreign)

/* Sub-Group: Those Who View HIV/AIDS as One of the Three Most Important Issues or The Most Important Issue in India*/
/* Hypothesis: This group will exhibit more responsiveness to the treatment */
 
* Foreign Aid Contribution to Social Services
ttest f if hiv2 > 2, by(t_USOnlyvControl)			
ttest f if hiv2 > 2, by(t_USLocalvControl)			
ttest f if hiv2 > 2, by(t_USINGOvControl)			
ttest f if hiv2 > 2, by(t_CvControl)
ttest f if hiv2 > 2, by(t_USvControl)
ttest f if hiv2 > 2, by(t_foreign)					

* Prime Minister Favorability Rating
ttest insts_1 if hiv2 > 2, by(t_USOnlyvControl)		
ttest insts_1 if hiv2 > 2, by(t_USLocalvControl)		
ttest insts_1 if hiv2 > 2, by(t_USINGOvControl)
ttest insts_1 if hiv2 > 2, by(t_CvControl)
ttest insts_1 if hiv2 > 2, by(t_USvControl)
ttest insts_1 if hiv2 > 2, by(t_foreign)

* Lok Sabha Favorability Rating
ttest insts_2 if hiv2 > 2, by(t_USOnlyvControl)		
ttest insts_2 if hiv2 > 2, by(t_USLocalvControl)		
ttest insts_2 if hiv2 > 2, by(t_USINGOvControl)		
ttest insts_2 if hiv2 > 2, by(t_CvControl)			
ttest insts_2 if hiv2 > 2, by(t_USvControl)
ttest insts_2 if hiv2 > 2, by(t_foreign)

* National Government Performance on HIV/AIDS
ttest nat if hiv2 > 2, by(t_USOnlyvControl)			
ttest nat if hiv2 > 2, by(t_USLocalvControl)			
ttest nat if hiv2 > 2, by(t_USINGOvControl)			
ttest nat if hiv2 > 2, by(t_CvControl)				
ttest nat if hiv2 > 2, by(t_USvControl)
ttest nat if hiv2 > 2, by(t_foreign)

* State Government Performance on HIV/AIDS
ttest s if hiv2 > 2, by(t_USOnlyvControl)			
ttest s if hiv2 > 2, by(t_USLocalvControl)
ttest s if hiv2 > 2, by(t_USINGOvControl)
ttest s if hiv2 > 2, by(t_CvControl)					
ttest s if hiv2 > 2, by(t_USvControl)
ttest s if hiv2 > 2, by(t_foreign)
 
 
 
 /* End of File */
